import React, { useState, useRef, useEffect, useContext } from 'react'
import { Link } from 'react-router-dom'
import { Button, Grow, Paper, Popper, MenuItem, MenuList } from '@material-ui/core';
import { withStyles } from '@material-ui/styles';
import styled from 'styled-components'

import { Store } from '../Store';

const styles = theme => ({
  root: {
    display: 'flex',
    
  },
  paper: {
    marginRight: '2px',  
  },
});

const DropdownStyled = styled.div`
  *{
    margin: 0 !important;
    text-decoration: none;
  }
  Button{
    text-transform: capitalize;
  }

`


function Dropdown(props) {
  const [open, setOpen] = useState(false);


  const innerDropdown = useRef(null)

  const { state , dispatch } = useContext(Store)
    
  useEffect(()=>{
    const handleClickOutside = (event) => {
      innerDropdown.current && !innerDropdown.current.contains(event.target) && setOpen(false)
    }
      
    document.addEventListener('mousedown', handleClickOutside)

    return () => document.removeEventListener('mousedown', handleClickOutside)
  
  },[])


  const handleToggle = () => {
    setOpen(true)
    if(state.searchOpen)
      dispatch({
        type: 'HANDLE_SEARCH_BAR',
        opened: false
      })
  }

  return (
    <DropdownStyled ref={innerDropdown}>
      <Button
        aria-controls="menu-list-grow"
        aria-haspopup="true"
        onClick={handleToggle}
      >
        {props.name}
      </Button>
      { open &&
        <Popper open={open} keepMounted transition disablePortal>
          {({ TransitionProps, placement }) => (
            <Grow
              {...TransitionProps}
              style={{ transformOrigin: placement === 'bottom' ? 'center top' : 'center bottom' }}
            >
              <Paper id="menu-list-grow">
                <MenuList>
                  {
                    props.items.map((item)=>
                      <Link key={item.name} to={item.href} ><MenuItem>{item.name}</MenuItem></Link>
                    )
                  }
                </MenuList>
              </Paper>
            </Grow>
          )}
        </Popper>
      }
    </DropdownStyled>
  );
}

export default withStyles(styles)(Dropdown)
